@@ -15,7 +15,7 @@ import papermill as pm
 from notebooker.constants import CANCEL_MESSAGE, JobStatus, NotebookResultComplete, NotebookResultError
 from notebooker.serialization.serialization import Serializer, get_serializer_from_cls
 from notebooker.utils.conversion import _output_ipynb_name, generate_ipynb_from_py, ipython_to_html, ipython_to_pdf
-from notebooker.utils.filesystem import _cleanup_dirs, get_output_dir, get_template_dir, initialise_base_dirs, mkdir_p
+from notebooker.utils.filesystem import _cleanup_dirs, initialise_base_dirs
 from notebooker.utils.notebook_execution import _output_dir, send_result_email
 
 logging.basicConfig(level=logging.INFO)
@@ -338,10 +338,19 @@ def main(
         raise ValueError("Error! Please provide a --report-name.")
     mongo_db_name = mongo_db_name or os.environ.get("DATABASE_NAME", "notebooker")
     mongo_host = mongo_host or os.environ.get("MONGO_HOST", "research")
-    mongo_user = mongo_user or os.environ.get("MONGO_USER", "research")
-    os.environ["MONGO_USER"] = mongo_user
-    mongo_password = mongo_password or os.environ.get("MONGO_PASSWORD", "research")
-    os.environ["MONGO_PASSWORD"] = mongo_password  # FIXME: rather insecure..
+
+    mongo_user = mongo_user if mongo_user is not None else os.environ.get("MONGO_USER")
+    if mongo_user is None:
+        os.environ.pop("MONGO_USER", None)
+    else:
+        os.environ["MONGO_USER"] = mongo_user
+
+    mongo_password = mongo_password if mongo_password is not None else os.environ.get("MONGO_PASSWORD")
+    if mongo_password is None:
+        os.environ.pop("MONGO_PASSWORD", None)
+    else:
+        os.environ["MONGO_PASSWORD"] = mongo_password  # FIXME: rather insecure..
+
     result_collection_name = result_collection_name or os.environ.get("RESULT_COLLECTION_NAME", "NOTEBOOK_OUTPUT")
     if notebook_kernel_name:
         os.environ["NOTEBOOK_KERNEL_NAME"] = notebook_kernel_name
@@ -374,6 +383,8 @@ def main(
         database_name=mongo_db_name,
         mongo_host=mongo_host,
         result_collection_name=result_collection_name,
+        user=mongo_user,
+        password=mongo_password,
     )
     results = []
     for overrides in all_overrides:
@@ -410,17 +421,17 @@ def docker_compose_entrypoint():
     Examples
     --------
     notebooker_execute --report-name watchdog_checks --mongo-host mktdatad
-Recieved a request to run a report with the following parameters:
+Received a request to run a report with the following parameters:
 ['/users/is/jbannister/pyenvs/notebooker/bin/python', '-m', 'notebooker.execute_notebook', '--report-name', 'watchdog_checks', '--mongo-host', 'mktdatad']
 ...
 
     notebooker_execute
-Recieved a request to run a report with the following parameters:
+Received a request to run a report with the following parameters:
 ['/users/is/jbannister/pyenvs/notebooker/bin/python', '-m', 'notebooker.execute_notebook']
 ValueError: Error! Please provide a --report-name.
     """
     args_to_execute = [sys.executable, "-m", __name__] + sys.argv[1:]
-    logger.info("Recieved a request to run a report with the following parameters:")
+    logger.info("Received a request to run a report with the following parameters:")
     logger.info(args_to_execute)
     try:
         subprocess.Popen(args_to_execute).wait()
